'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var umiSerializersCore = require('@metaplex-foundation/umi-serializers-core');
var errors = require('./errors.cjs');
var sumSerializerSizes = require('./sumSerializerSizes.cjs');

function getResolvedSize(size, childrenSizes, bytes, offset) {
  if (typeof size === 'number') {
    return [size, offset];
  }
  if (typeof size === 'object') {
    return size.deserialize(bytes, offset);
  }
  if (size === 'remainder') {
    const childrenSize = sumSerializerSizes.sumSerializerSizes(childrenSizes);
    if (childrenSize === null) {
      throw new umiSerializersCore.ExpectedFixedSizeSerializerError('Serializers of "remainder" size must have fixed-size items.');
    }
    const remainder = bytes.slice(offset).length;
    if (remainder % childrenSize !== 0) {
      throw new errors.InvalidArrayLikeRemainderSizeError(remainder, childrenSize);
    }
    return [remainder / childrenSize, offset];
  }
  throw new errors.UnrecognizedArrayLikeSerializerSizeError(size);
}
function getSizeDescription(size) {
  return typeof size === 'object' ? size.description : `${size}`;
}
function getSizeFromChildren(size, childrenSizes) {
  if (typeof size !== 'number') return null;
  if (size === 0) return 0;
  const childrenSize = sumSerializerSizes.sumSerializerSizes(childrenSizes);
  return childrenSize === null ? null : childrenSize * size;
}
function getSizePrefix(size, realSize) {
  return typeof size === 'object' ? size.serialize(realSize) : new Uint8Array();
}

exports.getResolvedSize = getResolvedSize;
exports.getSizeDescription = getSizeDescription;
exports.getSizeFromChildren = getSizeFromChildren;
exports.getSizePrefix = getSizePrefix;
//# sourceMappingURL=utils.cjs.map
